
# Slot: lone slot joe




URI: [http://example.org/sample/example1/lone_slot_joe](http://example.org/sample/example1/lone_slot_joe)


## Domain and Range

[MetricResult](MetricResult.md) &#8594;  <sub>0..1</sub> [String](types/String.md)

## Parents


## Children


## Used by

